@@ -24,7 +24,7 @@
 mod lex;
 mod parse;
 
-pub use parse::{Identifier, Makefile, Rule, VariableDefinition, ParseError, Error};
+pub use parse::{Error, Identifier, Include, Makefile, ParseError, Rule, VariableDefinition};
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 #[allow(non_camel_case_types)]
@@ -53,6 +53,10 @@ pub enum SyntaxKind {
     RECIPE,
     VARIABLE,
     EXPR,
+
+    // Directives
+    CONDITIONAL,
+    INCLUDE,
 }
 
 /// Convert our `SyntaxKind` into the rowan `SyntaxKind`.
